@@ -1,8 +1,6 @@
 use crate::{Bufferable, WriteLayered};
-use std::{
-    fmt::{self, Arguments},
-    io::{self, IoSlice, Write},
-};
+use std::fmt::{self, Arguments};
+use std::io::{self, IoSlice, Write};
 #[cfg(windows)]
 use unsafe_io::os::windows::{
     AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
@@ -10,7 +8,7 @@ use unsafe_io::os::windows::{
 #[cfg(not(windows))]
 use {
     io_lifetimes::{AsFd, BorrowedFd},
-    unsafe_io::os::posish::{AsRawFd, RawFd},
+    unsafe_io::os::rsix::{AsRawFd, RawFd},
 };
 
 /// Adapts a [`std::io::Write`] to implement [`WriteLayered`].
